@@ -31,14 +31,22 @@
   javaCheck <- function() {
     # Java version check, without .jinit (we do .jpackage after downloading resources)
     rawVersion <- system2("java", c("-version"), stdout = TRUE, stderr = TRUE)
-    jv <- regmatches(rawVersion[1], regexpr("[0-9]+\\.[0-9\\.]*", rawVersion[1]))
-    twoFirst <- substr(jv, 1L, 2L)
-    if(twoFirst == "1.") {
-      jvn <- as.numeric(substr(jv,3L,3L))
-    } else {
-      jvn <- as.numeric(twoFirst)
+    jv <- regmatches(rawVersion[1], regexpr("[0-9\\.]+", rawVersion[1]))
+    if (nchar(jv)<1) {
+      stop(paste0("unable to parse java version from", paste0(rawVersion, collapse=" "), "; is java installed correctly ?"))
     }
-    if (jvn<8 || jvn>15) stop(paste0("XLConnect is compatible with Java versions 8 to 15. Detected java version: ",jv))
+    else if(nchar(jv)==1) {
+       jvn <- as.numeric(jv)
+    }
+    else {
+      twoFirst <- substr(jv, 1L, 2L)
+      if(twoFirst == "1.") {
+        jvn <- as.numeric(substr(jv,3L,3L))
+      } else {
+        jvn <- as.numeric(twoFirst)
+      }
+    }
+    if (jvn<8 || jvn>16) stop(paste0("XLConnect is compatible with Java versions 8 to 16. Detected java version: ",jv))
   }
   javaCheck()
   repo <- Sys.getenv("XLCONNECT_JAVA_REPO_URL")
@@ -47,7 +55,8 @@
   }
   apachePrefix <- paste0(repo, "/org/apache")
   sharedPaths <- tryCatch({
-    c(xlcEnsureDependenciesFor(
+    c(
+      xlcEnsureDependenciesFor(
       paste0(apachePrefix, "/poi/poi-ooxml-schemas/4.1.2/poi-ooxml-schemas-4.1.2.jar"), "poi-ooxml-schemas.jar", 
       "4\\.[1-9].*",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
     xlcEnsureDependenciesFor(
@@ -73,8 +82,16 @@
       "1\\.(1[1-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-codec-java", rpmpkg="apache-commons-codec"),
     xlcEnsureDependenciesFor(
       paste0(apachePrefix, "/poi/ooxml-schemas/1.4/ooxml-schemas-1.4.jar"), "ooxml-schemas.jar",
-      "1\\.([4-9]|[1-9][0-9]).*",  libname, pkgname))
-  })
+      "1\\.([4-9]|[1-9][0-9]).*",  libname, pkgname),
+    xlcEnsureDependenciesFor(
+      paste0(repo, "/com/zaxxer/SparseBitSet/1.2/SparseBitSet-1.2.jar"), "SparseBitSet.jar",
+      "1\\.([2-9]|[1-9][0-9]).*",  libname, pkgname)
+    )
+  },
+  error=function(e) {
+          e
+        }
+  )
   .jpackage(name = pkgname, jars = "*", morePaths = sharedPaths)
   # Perform general XLConnect settings - pass package description
   XLConnectSettings(packageDescription(pkgname))
